@@ -5,6 +5,7 @@ Organization model
 from dataclasses import dataclass
 
 from . import VersionedModel
+from typing import Optional
 
 
 @dataclass
@@ -12,8 +13,8 @@ class Organization(VersionedModel):
     """An organization model."""
 
     name: str = None
-    code: str = None
-    description: str = None
+    code: Optional[str] = None
+    description: Optional[str] = None
     # members (with accompanied roles, including `owner`) are maintained through `PersonOrganizationRole`
 
     # TODO: to see do we want redundancy, to have a relationship from an `Organization` to its `owner`
